class puppet_enterprise::master(
  $metrics_enabled,
  $metrics_server_id,
  $metrics_jmx_enabled,
  $metrics_graphite_enabled,
  $metrics_graphite_host,
  $metrics_graphite_port,
  $metrics_graphite_update_interval_seconds,
  $profiler_enabled,
  $certname                                  = $::client_cert,
  $static_files                              = {},
  $localcacert                               = $puppet_enterprise::params::localcacert,
  $java_args                                 = $puppet_enterprise::params::puppetserver_java_args,
) inherits puppet_enterprise::params {

  include puppet_enterprise::packages
  Package <| tag == 'pe-master-packages' |>

  class { 'puppet_enterprise::master::puppetserver':
    certname                                 => $certname,
    localcacert                              => $localcacert,
    static_files                             => $static_files,
    java_args                                => $java_args,
    metrics_enabled                          => $metrics_enabled,
    metrics_server_id                        => $metrics_server_id,
    metrics_jmx_enabled                      => $metrics_jmx_enabled,
    metrics_graphite_enabled                 => $metrics_graphite_enabled,
    metrics_graphite_host                    => $metrics_graphite_host,
    metrics_graphite_port                    => $metrics_graphite_port,
    metrics_graphite_update_interval_seconds => $metrics_graphite_update_interval_seconds,
    profiler_enabled                         => $profiler_enabled,
  }

  File {
    ensure  => directory,
    owner   => 'pe-puppet',
    group   => 'pe-puppet',
    mode    => '0644',
  }

  file { '/etc/puppetlabs/puppet/environments': }

  # FIXME PACKAGING Should the packages set the permissions correctly?
  file { '/var/log/pe-puppet' :
    mode    => '0640',
  }


  # Start
  # puppet.conf
  Pe_ini_setting {
    ensure  => present,
    path    => '/etc/puppetlabs/puppet/puppet.conf',
    section => 'master',
  }

  pe_ini_setting { 'certname' :
    setting => 'certname',
    value   => $certname,
  }

  pe_ini_setting { 'server':
    setting => 'server',
    value   => $certname,
  }

  pe_ini_setting { 'always_cache_features' :
    setting => 'always_cache_features',
    value   => 'true',
  }
  # End
}
